aboutsummaryrefslogtreecommitdiff
path: root/src/armnn/test/InstrumentTests.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/armnn/test/InstrumentTests.cpp')
-rw-r--r--src/armnn/test/InstrumentTests.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/armnn/test/InstrumentTests.cpp b/src/armnn/test/InstrumentTests.cpp
index 11d8414296..40ffde8801 100644
--- a/src/armnn/test/InstrumentTests.cpp
+++ b/src/armnn/test/InstrumentTests.cpp
@@ -13,7 +13,7 @@ using namespace armnn;
BOOST_AUTO_TEST_SUITE(Instruments)
-BOOST_AUTO_TEST_CASE(WallClockTimerInMilliseconds)
+BOOST_AUTO_TEST_CASE(WallClockTimerInMicroseconds)
{
WallClockTimer wallClockTimer;
@@ -22,16 +22,16 @@ BOOST_AUTO_TEST_CASE(WallClockTimerInMilliseconds)
// start the timer
wallClockTimer.Start();
- // wait for 10 milliseconds
- std::this_thread::sleep_for(std::chrono::milliseconds(10));
+ // wait for 10 microseconds
+ std::this_thread::sleep_for(std::chrono::microseconds(10));
// stop the timer
wallClockTimer.Stop();
BOOST_CHECK_EQUAL(wallClockTimer.GetMeasurements().front().m_Name, WallClockTimer::WALL_CLOCK_TIME);
- // check that WallClockTimer measurement should be >= 10 milliseconds
- BOOST_CHECK_GE(wallClockTimer.GetMeasurements().front().m_Value, std::chrono::milliseconds(10).count());
+ // check that WallClockTimer measurement should be >= 10 microseconds
+ BOOST_CHECK_GE(wallClockTimer.GetMeasurements().front().m_Value, std::chrono::microseconds(10).count());
}
BOOST_AUTO_TEST_CASE(WallClockTimerInNanoseconds)
@@ -43,7 +43,7 @@ BOOST_AUTO_TEST_CASE(WallClockTimerInNanoseconds)
// start the timer
wallClockTimer.Start();
// wait for 500 nanoseconds - 0.0005 milliseconds
std::this_thread::sleep_for(std::chrono::nanoseconds(500));
// stop the timer
@@ -51,11 +51,11 @@ BOOST_AUTO_TEST_CASE(WallClockTimerInNanoseconds)
BOOST_CHECK_EQUAL(wallClockTimer.GetMeasurements().front().m_Name, WallClockTimer::WALL_CLOCK_TIME);
- // delta is 0.0005 milliseconds
+ // delta is 0.5 microseconds
const auto delta =
- std::chrono::duration_cast<std::chrono::duration<double, std::milli>>(std::chrono::nanoseconds(500));
+ std::chrono::duration_cast<std::chrono::duration<double, std::micro>>(std::chrono::nanoseconds(500));
- // check that WallClockTimer measurement should be >= 0.0005 milliseconds
+ // check that WallClockTimer measurement should be >= 0.5 microseconds
BOOST_CHECK_GE(wallClockTimer.GetMeasurements().front().m_Value, delta.count());
}
@@ -43,7 +43,7 @@ BOOST_AUTO_TEST_CASE(WallClockTimerInNanoseconds)
// start the timer
wallClockTimer.Start();
- // wait for 500 nanoseconds - 0.0005 milliseconds
+ // wait for 500 nanoseconds - 0.5 microseconds
std::this_thread::sleep_for(std::chrono::nanoseconds(500));
// stop the timer